Turnt Changelog
===============

1.1.0 (2019-09-12)
------------------

A new `--print` option enables a convenient mode for debugging tests that just shows the output instead of checking any results.


1.0.0 (2019-09-03)
------------------

Initial release.
